@@ -816,6 +816,8 @@ class DevMgr5(Ui_MainWindow_Derived, Ui_MainWindow, QMainWindow):
 
 
     def updateWindowTitle(self):
+        if self.cur_device is None or self.cur_printer is None:
+            return
         if self.cur_device.device_type == DEVICE_TYPE_FAX:
                 self.setWindowTitle(self.__tr("HP Device Manager - %s (Fax)"%self.cur_device.model_ui))
         else:
@@ -1848,7 +1850,7 @@ class DevMgr5(Ui_MainWindow_Derived, Ui_MainWindow, QMainWindow):
             self.InstallLatestButton.setEnabled(True)
         else:
             self.InstallLatestButton_lock = True
-            utils.openURL("http://hplipopensource.com/hplip-web/install/manual/index.html")
+            utils.openURL("https://developers.hp.com/hp-linux-imaging-and-printing/install/manual/index.html")
             QTimer.singleShot(1000, self.InstallLatestButton_unlock)
 
 
@@ -1876,6 +1878,8 @@ class DevMgr5(Ui_MainWindow_Derived, Ui_MainWindow, QMainWindow):
 
 
     def updatePrintControlTab(self):
+        if self.cur_device is None or self.cur_printer is None:
+            return
         if self.cur_device.device_type == DEVICE_TYPE_PRINTER:
             self.PrintControlPrinterNameLabel.setText(self.__tr("Printer Name:"))
             self.groupBox.setTitle(QApplication.translate("MainWindow", "Printer Queue Control", None))
